@@ -7,6 +7,7 @@ from tokenize_rt import Offset
 from tokenize_rt import Token
 
 from pyupgrade._ast_helpers import ast_to_offset
+from pyupgrade._ast_helpers import is_async_listcomp
 from pyupgrade._data import register
 from pyupgrade._data import State
 from pyupgrade._data import TokenFunc
@@ -31,6 +32,7 @@ def visit_Assign(
             state.settings.min_version >= (3,) and
             len(node.targets) == 1 and
             isinstance(node.targets[0], ast.Tuple) and
-            isinstance(node.value, ast.ListComp)
+            isinstance(node.value, ast.ListComp) and
+            not is_async_listcomp(node.value)
     ):
         yield ast_to_offset(node.value), _replace_list_comprehension
