@@ -3,9 +3,9 @@ import re
 import string
 import sys
 
-if sys.version_info >= (3, 7):  # pragma: no cover (py37+)
+if sys.version_info >= (3, 7):  # pragma: >=3.7 cover
     is_ascii = str.isascii
-else:  # pragma: no cover (<py37)
+else:  # pragma: <3.7 cover
     def is_ascii(s: str) -> bool:
         return all(c in string.printable for c in s)
 
